@@ -46,7 +46,7 @@
  * version number.  Used together with oath_check_version() to verify
  * header file and run-time library consistency.
  */
-#define OATH_VERSION "1.10.2"
+#define OATH_VERSION "1.10.3"
 
 /**
  * OATH_VERSION_NUMBER
@@ -56,7 +56,7 @@
  * this symbol will have the value 0x01020300.  The last two digits
  * are only used between public releases, and will otherwise be 00.
  */
-#define OATH_VERSION_NUMBER 0x010a0200
+#define OATH_VERSION_NUMBER 0x010a0100
 
 /**
  * oath_rc:
@@ -79,6 +79,7 @@
  * @OATH_FILE_RENAME_ERROR: System error when renaming file
  * @OATH_FILE_UNLINK_ERROR: System error when removing file
  * @OATH_TIME_ERROR: System error for time manipulation
+ * @OATH_STRCMP_ERROR: A strcmp callback returned an error
  *
  * Return codes for OATH functions.  All return codes are negative
  * except for the successful code OATH_OK which are guaranteed to be
@@ -107,7 +108,8 @@ typedef enum
   OATH_FILE_LOCK_ERROR = -15,
   OATH_FILE_RENAME_ERROR = -16,
   OATH_FILE_UNLINK_ERROR = -17,
-  OATH_TIME_ERROR = -18
+  OATH_TIME_ERROR = -18,
+  OATH_STRCMP_ERROR = -19
 } oath_rc;
 
 /* Global */
@@ -153,8 +155,10 @@ oath_hotp_validate (const char *secret,
  * oath_hotp_validate_callback() or oath_totp_validate_callback() to
  * validate OTPs.
  *
- * The function should behave like strcmp, i.e., only ever return 0 on
- * matches.
+ * The function should be similar to strcmp in that it return 0 only
+ * on matches.  It differs by permitting use of negative return codes
+ * as indication of internal failures in the callback.  Positive
+ * values indicate OTP mismatch.
  *
  * This callback interface is useful when you cannot compare OTPs
  * directly using normal strcmp, but instead for example only have a
@@ -163,7 +167,8 @@ oath_hotp_validate (const char *secret,
  * test_otp OTP using the same hash, and then compare the results.
  *
  * Return value: 0 if and only if @test_otp is identical to the OTP to
- *   be validated.
+ *   be validated.  Negative value if an internal failure occurs.
+ *   Positive value if the test_otp simply doesn't match.
  *
  * Since: 1.6.0
  **/
